IElixir v0.9.18 IElixir.Socket.IOPub View Source
"IOPub: this socket is the ‘broadcast channel’ where the kernel publishes all side effects (stdout, stderr, etc.) as well as the requests coming from any client over the shell socket and its own requests on the stdin socket." From https://ipython.org/ipython-doc/dev/development/messaging.html
Link to this section Summary
Functions
Returns a specification to start this module under a supervisor.
Invoked when the server is started. start_link/3 or start/3 will
block until it returns.
Send error message. Send traceback so client can have information about what went wrong.
Send execute_input message. Send information about 'execution_count'.
Send execute_result message. This is used for sending what executed code returned.
Send stream message but with a mime type of HTML, so the content is interpolated into the result
Send stream message but with a mime type of IMAGE, so the content is interpolated into the result
Send status of sandbox: 'ok' | 'error' | 'abort'.
Send stream message. This is used for sending output of code execution.
Link to this section Functions
child_spec(init_arg) View Source
Returns a specification to start this module under a supervisor.
See Supervisor.
init(opts) View Source
Invoked when the server is started. start_link/3 or start/3 will
block until it returns.
init_arg is the argument term (second argument) passed to start_link/3.
Returning {:ok, state} will cause start_link/3 to return
{:ok, pid} and the process to enter its loop.
Returning {:ok, state, timeout} is similar to {:ok, state}
except handle_info(:timeout, state) will be called after timeout
milliseconds if no messages are received within the timeout.
Returning {:ok, state, :hibernate} is similar to {:ok, state}
except the process is hibernated before entering the loop. See
c:handle_call/3 for more information on hibernation.
Returning {:ok, state, {:continue, continue}} is similar to
{:ok, state} except that immediately after entering the loop
the c:handle_continue/2 callback will be invoked with the value
continue as first argument.
Returning :ignore will cause start_link/3 to return :ignore and
the process will exit normally without entering the loop or calling
c:terminate/2. If used when part of a supervision tree the parent
supervisor will not fail to start nor immediately try to restart the
GenServer. The remainder of the supervision tree will be started
and so the GenServer should not be required by other processes.
It can be started later with Supervisor.restart_child/2 as the child
specification is saved in the parent supervisor. The main use cases for
this are:
- The
GenServeris disabled by configuration but might be enabled later. - An error occurred and it will be handled by a different mechanism than the
Supervisor. Likely this approach involves callingSupervisor.restart_child/2after a delay to attempt a restart.
Returning {:stop, reason} will cause start_link/3 to return
{:error, reason} and the process to exit with reason reason without
entering the loop or calling c:terminate/2.
Callback implementation for GenServer.init/1.
send_error(message, execution_count, exception_name, traceback) View Source
Send error message. Send traceback so client can have information about what went wrong.
send_execute_input(message, execution_count) View Source
Send execute_input message. Send information about 'execution_count'.
send_execute_result(message, text) View Source
Send execute_result message. This is used for sending what executed code returned.
send_html(message, text) View Source
Send stream message but with a mime type of HTML, so the content is interpolated into the result
send_image(message, execution_count, image) View Source
Send stream message but with a mime type of IMAGE, so the content is interpolated into the result
send_status(status, message) View Source
Send status of sandbox: 'ok' | 'error' | 'abort'.
send_stream(message, text, stream_name \\ "stdout") View Source
Send stream message. This is used for sending output of code execution.