IElixir v0.9.18 IElixir.Utils View Source
IElixir.Utils module contains various methods that makes code more readable. However, those methods may be useful during development of IElixir, testing them can conserve implementation which we would like to avoid.
Link to this section Summary
Functions
Parse connection file and return map with proper fields.
Link to this section Functions
Link to this function
parse_connection_file(connection_file) View Source
Parse connection file and return map with proper fields.
Example
iex> conn_info = IElixir.Utils.parse_connection_file("test/test_connection_file"); :ok
:ok
iex> conn_info["key"]
"7534565f-e742-40f3-85b4-bf4e5f35390a"