IElixir v0.9.18 Boyle View Source
This module is responsible for runtime package management. Name of the package honours remarkable chemist, Robert Boyle. This package allows you to manage your Elixir virtual enviromnent without need of restarting erlang virtual machine. Boyle installs environment into ./envs/you_new_environment directory and creates new mix project there with requested dependencies. It keeps takes care of fetching, compiling and loading/unloading modules from dependencies list of that environment.
You can also use this environment as a separate mix project and run it interactively with iex -S mix from the environment directory.
Link to this section Summary
Types
Return values of start* functions
Functions
Activate environment and load all modules that are installed within this module.
Get name of active environment.
Returns a specification to start this module under a supervisor.
Activate environment and unload all modules that are installed within this module.
Get absolute path of active environment.
Show detailed dependencies in the current environment stored in mix.lock file created for the environment.
Invoked when the server is started. start_link/3 or start/3 will
block until it returns.
Activate environment and unload all modules that are installed within this module.
List all available environemnts created in the past.
Create new virtual environment where your modules will be stored and compiled.
Print list of modules paths and loaded modules.
Make sure all dependencies are fetched, compiled and loaded.
Remove existing environment.
Get state of Boyle module, some internal paths useful for loaded modules management.
Link to this section Types
on_start() View Source
Return values of start* functions
Link to this section Functions
activate(name) View Source
Activate environment and load all modules that are installed within this module.
Examples
iex> Boyle.activate("boyle_test_env")
:ok
iex> Boyle.deactivate()
:ok
active_env_name() View Source
Get name of active environment.
Examples
iex> Boyle.activate("boyle_test_env")
:ok
iex> Boyle.active_env_name()
"boyle_test_env"
child_spec(init_arg) View Source
Returns a specification to start this module under a supervisor.
See Supervisor.
deactivate() View Source
Activate environment and unload all modules that are installed within this module.
Examples
iex> Boyle.activate("boyle_test_env")
:ok
iex> Boyle.deactivate()
:ok
environment_path() View Source
Get absolute path of active environment.
freeze() View Source
Show detailed dependencies in the current environment stored in mix.lock file created for the environment.
Examples
iex> Boyle.activate("boyle_test_env")
:ok
iex> Boyle.freeze()
{%{decimal:
{:hex,
:decimal,
"1.7.0",
"30d6b52c88541f9a66637359ddf85016df9eb266170d53105f02e4a67e00c5aa",
[:mix],
[],
"hexpm"}},
[]}
iex> Boyle.deactivate()
:ok
init(opts) View Source
Invoked when the server is started. start_link/3 or start/3 will
block until it returns.
init_arg is the argument term (second argument) passed to start_link/3.
Returning {:ok, state} will cause start_link/3 to return
{:ok, pid} and the process to enter its loop.
Returning {:ok, state, timeout} is similar to {:ok, state}
except handle_info(:timeout, state) will be called after timeout
milliseconds if no messages are received within the timeout.
Returning {:ok, state, :hibernate} is similar to {:ok, state}
except the process is hibernated before entering the loop. See
c:handle_call/3 for more information on hibernation.
Returning {:ok, state, {:continue, continue}} is similar to
{:ok, state} except that immediately after entering the loop
the c:handle_continue/2 callback will be invoked with the value
continue as first argument.
Returning :ignore will cause start_link/3 to return :ignore and
the process will exit normally without entering the loop or calling
c:terminate/2. If used when part of a supervision tree the parent
supervisor will not fail to start nor immediately try to restart the
GenServer. The remainder of the supervision tree will be started
and so the GenServer should not be required by other processes.
It can be started later with Supervisor.restart_child/2 as the child
specification is saved in the parent supervisor. The main use cases for
this are:
- The
GenServeris disabled by configuration but might be enabled later. - An error occurred and it will be handled by a different mechanism than the
Supervisor. Likely this approach involves callingSupervisor.restart_child/2after a delay to attempt a restart.
Returning {:stop, reason} will cause start_link/3 to return
{:error, reason} and the process to exit with reason reason without
entering the loop or calling c:terminate/2.
Callback implementation for GenServer.init/1.
install(new_dep) View Source
Activate environment and unload all modules that are installed within this module.
Examples
iex> Boyle.activate("boyle_test_env")
:ok
iex> Boyle.install({:decimal, "~> 1.5.0"})
:ok
iex> Boyle.deactivate()
:ok
list() View Source
List all available environemnts created in the past.
Examples
iex> {:ok, envs_list} = Boyle.list() iex> "boyle_test_env" in envs_list true
mk(name) View Source
Create new virtual environment where your modules will be stored and compiled.
Examples
iex> {:ok, envs_list} = Boyle.mk("test_env")
iex> "test_env" in envs_list
true
paths() View Source
Print list of modules paths and loaded modules.
reinstall() View Source
Make sure all dependencies are fetched, compiled and loaded.
rm(name) View Source
Remove existing environment.
Examples
iex> {:ok, envs_list} = Boyle.rm("test_env_for_removal")
iex> "test_env_for_removal" in envs_list
false
start_link(opts) View Source
state() View Source
Get state of Boyle module, some internal paths useful for loaded modules management.